# Generated by Django 4.2.3 on 2023-08-03 00:03

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0069_alter_healtheconomicshouseholdhead_hoh_employment_type_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="healtheconomicshouseholdhead",
            new_name="hoh_ethnicity_old",
            old_name="hoh_ethnicity",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicshouseholdhead",
            new_name="hoh_ethnicity_old",
            old_name="hoh_ethnicity",
        ),
    ]
