# Generated by Django 4.1.7 on 2023-05-02 22:40

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0025_patientlogreportprinthistory_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalpatientlog",
            name="filing_identifier",
            field=models.CharField(
                db_index=True,
                default=uuid.uuid4,
                help_text="A sequential number to label a manual patient file",
                max_length=36,
                verbose_name="File number",
            ),
        ),
        migrations.AlterField(
            model_name="patientlog",
            name="filing_identifier",
            field=models.CharField(
                default=uuid.uuid4,
                help_text="A sequential number to label a manual patient file",
                max_length=36,
                unique=True,
                verbose_name="File number",
            ),
        ),
    ]
