# Generated by Django 4.2.4 on 2023-08-23 15:53

import _socket
import django.core.validators
import django_audit_fields.fields.hostname_modification_field
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0108_alter_concomitantmedication_device_created_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="dwelling_value_known",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="in local currency",
                max_length=25,
                verbose_name="If the owner [you] were to sell this dwelling today, do you know the approximate value?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="water_obtain_time",
            field=models.CharField(
                choices=[
                    ("on_premises", "Water on premises (includes water piped to a neighbour)"),
                    ("less_30min", "Less than 30 minutes"),
                    ("greater_30min", "30 minutes or longer"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="How long does it take to obtain drinking water?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_employment_status",
            field=models.CharField(
                choices=[
                    ("1", "Full time employed"),
                    ("2", "Regular part time employed "),
                    ("9", "Self employed "),
                    ("3", "Irregular/ occasional/ day worker employment"),
                    ("4", "Non-paid/ voluntary role "),
                    ("5", "Student"),
                    ("6", "Homemaker"),
                    ("7", "Unemployed (able to work)"),
                    ("8", "Unemployed (unable to work)"),
                    ("dont_know", "Don't know"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment",
                max_length=25,
                verbose_name="Household head’s employment status",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_marital_status",
            field=models.CharField(
                choices=[
                    ("1", "Never Married (but not co-habiting)"),
                    ("2", "Co-habiting"),
                    ("3", "Currently Married"),
                    ("4", "Separated/Divorced"),
                    ("5", "Widowed"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don't know"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Not applicable if patient is head of household",
                max_length=25,
                verbose_name="Household head’s marital status",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="relationship_to_hoh",
            field=models.CharField(
                choices=[
                    ("WIFE_HUSBAND", "Wife/Husband"),
                    ("SON_DAUGHTER", "Son/Daughter"),
                    ("SON_DAUGHTERINLAW", "Son/Daughter-in-law"),
                    ("GRANDCHILD", "Grandchild"),
                    ("PARENT", "Parent"),
                    ("PARENTINLAW", "Parent-in-law"),
                    ("BROTHER_SISTER", "Brother/Sister"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don't know"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Not applicable if patient is head of household",
                max_length=25,
                verbose_name="What is your relationship to the household head?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remit",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Money transfers from family members or friends residing outside the country",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remit_currency",
            field=models.CharField(
                blank=True,
                choices=[
                    ("USD", "USD"),
                    ("GBP", "GBP"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don't know"),
                ],
                max_length=50,
                null=True,
                verbose_name="In what currency do you receive remittances?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remit_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="financial_status",
            field=models.CharField(
                choices=[
                    ("1", "Very good"),
                    ("2", "Good"),
                    ("3", "Moderate"),
                    ("4", "Bad"),
                    ("5", "Very bad"),
                    ("DWTA", "Don't want to answer"),
                ],
                max_length=25,
                verbose_name="Would you say your household's financial situation is?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="financial_status_compare",
            field=models.CharField(
                choices=[
                    ("1", "Among most wealthy"),
                    ("2", "Above average "),
                    ("3", "Average wealth"),
                    ("4", "Below average"),
                    ("5", "Among least wealthy"),
                    ("DWTA", "Don't want to answer"),
                ],
                max_length=25,
                verbose_name="How would you rate your household’s financial situation compared with others in your community?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="household_debt",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                ],
                max_length=25,
                verbose_name="Does your household or any members of the household have current debt or outstanding loans?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="income_enough",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("Dont_know", "Don't know")],
                max_length=15,
                verbose_name="Thinking about the income for this household, do you believe that it is enough money to cover your daily living needs and obligations?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="interest",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text="(for example, from savings account or fixed deposits)?",
                max_length=15,
                verbose_name="Interest, dividends",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="interest_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="internal_remit",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Money transfers from family members or friends residing inside the country",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="internal_remit_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Do you have additional sources of income not included above?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="ngo_assistance",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Assistance from nongovernmental organization",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="ngo_assistance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="pension",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text="Pensions by work",
                max_length=15,
                verbose_name="State old-age (veteran's/civil service) pension*, contributory pension fund, provident fund or social security benefit?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="pension_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="rental_income",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Income from rental of property?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="rental_income_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="selling",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Earnings from selling, trading or hawking products?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="selling_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Income from wages, salary from job",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_employment_status",
            field=models.CharField(
                choices=[
                    ("1", "Full time employed"),
                    ("2", "Regular part time employed "),
                    ("9", "Self employed "),
                    ("3", "Irregular/ occasional/ day worker employment"),
                    ("4", "Non-paid/ voluntary role "),
                    ("5", "Student"),
                    ("6", "Homemaker"),
                    ("7", "Unemployed (able to work)"),
                    ("8", "Unemployed (unable to work)"),
                    ("dont_know", "Don't know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="What is your employment status?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_marital_status",
            field=models.CharField(
                choices=[
                    ("1", "Never Married (but not co-habiting)"),
                    ("2", "Co-habiting"),
                    ("3", "Currently Married"),
                    ("4", "Separated/Divorced"),
                    ("5", "Widowed"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don't know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="What is your marital status?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_additional",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                ],
                max_length=25,
                verbose_name="Do you own any other property other than your primary dwelling?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_owner",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Don't know"),
                    ("DWTA", "Don't want to answer"),
                ],
                max_length=25,
                verbose_name="Do you own any land.",
            ),
        ),
    ]
