# Generated by Django 4.1.2 on 2023-01-23 00:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_consent",
            "0005_remove_subjectconsent_unique_consent_subject_id_and_version_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalsubjectconsent",
            name="group_identifier",
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="subjectconsent",
            name="group_identifier",
            field=models.CharField(max_length=50, null=True),
        ),
    ]
