# Generated by Django 4.2.5 on 2023-09-12 14:57

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0114_alter_dmmedicationadherence_visual_score_confirmed_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalnextappointment",
            name="best_visit_code",
        ),
        migrations.RemoveField(
            model_name="historicalnextappointment",
            name="info_source_old",
        ),
        migrations.RemoveField(
            model_name="historicalnextappointment",
            name="old_health_facility",
        ),
        migrations.RemoveField(
            model_name="nextappointment",
            name="best_visit_code",
        ),
        migrations.RemoveField(
            model_name="nextappointment",
            name="info_source_old",
        ),
        migrations.RemoveField(
            model_name="nextappointment",
            name="old_health_facility",
        ),
        migrations.AddField(
            model_name="historicalsubjectvisitmissed",
            name="appt_date",
            field=models.DateField(
                help_text="Should fall on an Integrated clinic day",
                null=True,
                verbose_name="Next scheduled routine/facility appointment",
            ),
        ),
        migrations.AddField(
            model_name="subjectvisitmissed",
            name="appt_date",
            field=models.DateField(
                help_text="Should fall on an Integrated clinic day",
                null=True,
                verbose_name="Next scheduled routine/facility appointment",
            ),
        ),
    ]
