from .blood_results_fbc import BloodResultsFbc
from .blood_results_glu import BloodResultsGlu
from .blood_results_hba1c import BloodResultsHba1c
from .blood_results_ins import BloodResultsIns
from .blood_results_lft import BloodResultsLft
from .blood_results_lipid import BloodResultsLipid
from .blood_results_rft import BloodResultsRft
