from edc_constants.constants import COMMUNITY, DM, HIV, HTN, INTEGRATED, NCD, OTHER

list_data = {
    "edc_facility.healthfacilitytypes": [
        (COMMUNITY, "Community meeting place"),
        (INTEGRATED, "Facility Integrated Clinic"),
        (DM, "Diabetes Clinic"),
        (HIV, "HIV Clinic"),
        (HTN, "Hypertension Clinic"),
        (NCD, "NCD Clinic"),
        (OTHER, "Other (specify below)"),
    ],
}
