# Generated by Django 4.2.4 on 2023-08-16 21:30

from django.db import migrations
import edc_model_fields.fields.other_charfield


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0105_alter_historicallocationupdate_options_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="dmmedicationadherence",
            name="meds_shortage_reason_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If `other` reason for not having medications, specify",
            ),
        ),
        migrations.AddField(
            model_name="historicaldmmedicationadherence",
            name="meds_shortage_reason_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If `other` reason for not having medications, specify",
            ),
        ),
        migrations.AddField(
            model_name="historicalhivmedicationadherence",
            name="meds_shortage_reason_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If `other` reason for not having medications, specify",
            ),
        ),
        migrations.AddField(
            model_name="historicalhtnmedicationadherence",
            name="meds_shortage_reason_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If `other` reason for not having medications, specify",
            ),
        ),
        migrations.AddField(
            model_name="hivmedicationadherence",
            name="meds_shortage_reason_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If `other` reason for not having medications, specify",
            ),
        ),
        migrations.AddField(
            model_name="htnmedicationadherence",
            name="meds_shortage_reason_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If `other` reason for not having medications, specify",
            ),
        ),
    ]
