# Generated by Django 4.1.7 on 2023-04-18 09:36

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0017_alter_historicalpatientlog_group_identifier_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalpatientlog",
            name="age_in_years",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(18),
                    django.core.validators.MaxValueValidator(110),
                ],
                verbose_name="Age",
            ),
        ),
        migrations.AlterField(
            model_name="patientlog",
            name="age_in_years",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(18),
                    django.core.validators.MaxValueValidator(110),
                ],
                verbose_name="Age",
            ),
        ),
    ]
