# Generated by Django 4.2.1 on 2023-07-05 02:16

from django.db import migrations
import django.db.models.manager
import edc_sites.model_mixins
import intecomm_group.models.patient_group
import intecomm_screening.model_mixins.patient_call_model_mixin


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_group", "0013_alter_historicalpatientgroup_status_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="communitycarelocation",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Community Care Location",
                "verbose_name_plural": "Community Care Locations",
            },
        ),
        migrations.AlterModelOptions(
            name="patientfollowupcall",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ["report_datetime"],
                "verbose_name": "Patient Followup Call",
                "verbose_name_plural": "Patient Followup Calls",
            },
        ),
        migrations.AlterModelOptions(
            name="patientgroup",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Patient Group",
                "verbose_name_plural": "Patient Groups",
            },
        ),
        migrations.AlterModelOptions(
            name="patientgroupappointment",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Patient Group Appointment",
                "verbose_name_plural": "Patient Group Appointments",
            },
        ),
        migrations.AlterModelOptions(
            name="patientgroupmeeting",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
            },
        ),
        migrations.AlterModelManagers(
            name="communitycarelocation",
            managers=[
                ("on_site", edc_sites.model_mixins.CurrentSiteManager()),
                ("objects", django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="patientfollowupcall",
            managers=[
                (
                    "objects",
                    intecomm_screening.model_mixins.patient_call_model_mixin.Manager(),
                ),
                ("on_site", edc_sites.model_mixins.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="patientgroup",
            managers=[
                ("objects", intecomm_group.models.patient_group.PatientGroupManager()),
                ("on_site", edc_sites.model_mixins.CurrentSiteManager()),
            ],
        ),
    ]
