# Generated by Django 4.2.3 on 2023-08-07 22:50

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0092_healtheconomicsproperty_land_surface_area_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="About how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_value_known",
            field=models.CharField(
                default="QUESTION_RETIRED",
                help_text="Use cash equivalent in local currency",
                max_length=25,
                verbose_name="Do you know about how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="About how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_value_known",
            field=models.CharField(
                default="QUESTION_RETIRED",
                help_text="Use cash equivalent in local currency",
                max_length=25,
                verbose_name="Do you know about how much is this worth in total?",
            ),
        ),
    ]
