# Generated by Django 4.1.2 on 2022-11-22 23:57

from django.db import migrations, models
import django_crypto_fields.fields.encrypted_char_field


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0010_historicalpatientlog_age_in_years_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalpatientlog",
            old_name="hf_identifier",
            new_name="hospital_identifier",
        ),
        migrations.RenameField(
            model_name="patientlog",
            old_name="hf_identifier",
            new_name="hospital_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalpatientlog",
            name="last_4_hf_identifier",
        ),
        migrations.RemoveField(
            model_name="patientlog",
            name="last_4_hf_identifier",
        ),
        migrations.AddField(
            model_name="historicalpatientlog",
            name="last_4_hospital_identifier",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                editable=False,
                help_text="auto-populated (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Last 4 digits of hospital_identifier",
            ),
        ),
        migrations.AddField(
            model_name="patientlog",
            name="last_4_hospital_identifier",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                editable=False,
                help_text="auto-populated (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Last 4 digits of hospital_identifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="eligible",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to now", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="reasons_ineligible",
            field=models.TextField(
                max_length=150, null=True, verbose_name="Reason not eligible"
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="eligible",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                help_text="Date and time eligibility was determined relative to now", null=True
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="reasons_ineligible",
            field=models.TextField(
                max_length=150, null=True, verbose_name="Reason not eligible"
            ),
        ),
    ]
