# Generated by Django 4.1.7 on 2023-05-10 00:43

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_prn",
            "0005_rename_historicaloffschedulefollowup_historicaloffscheduleinte_and_more",
        ),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="historicaloffschedulecomm",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Off-schedule community-based integrated care",
                "verbose_name_plural": "historical Off-schedule community-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="historicaloffscheduleinte",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Off-schedule facility-based integrated care",
                "verbose_name_plural": "historical Off-schedule facility-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalonschedulecomm",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical On-schedule community-based integrated care",
                "verbose_name_plural": "historical On-schedule community-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalonscheduleinte",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical On-schedule facility-based integrated care",
                "verbose_name_plural": "historical On-schedule facility-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="offschedulecomm",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Off-schedule community-based integrated care",
                "verbose_name_plural": "Off-schedule community-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="offscheduleinte",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Off-schedule facility-based integrated care",
                "verbose_name_plural": "Off-schedule facility-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="onschedulecomm",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "On-schedule community-based integrated care",
                "verbose_name_plural": "On-schedule community-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="onscheduleinte",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "On-schedule facility-based integrated care",
                "verbose_name_plural": "On-schedule facility-based integrated care",
            },
        ),
    ]
