# Generated by Django 4.1.2 on 2023-01-23 15:48

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0006_alter_healtheconomics_options_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalotherbaselinedata",
            name="alcohol_consumption",
            field=models.CharField(
                choices=[
                    ("occasionally", "Occasionally"),
                    ("1_2_per_week", "1-2 times a week"),
                    ("3_4_per_week", "3-4 times a week"),
                    ("daily", "Daily"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If yes, how often do you drink alcohol?",
            ),
        ),
        migrations.AlterField(
            model_name="otherbaselinedata",
            name="alcohol_consumption",
            field=models.CharField(
                choices=[
                    ("occasionally", "Occasionally"),
                    ("1_2_per_week", "1-2 times a week"),
                    ("3_4_per_week", "3-4 times a week"),
                    ("daily", "Daily"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If yes, how often do you drink alcohol?",
            ),
        ),
    ]
