# Generated by Django 4.2.4 on 2023-08-28 17:10

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_consent", "0013_subjectconsentug"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="subjectconsentug",
            options={
                "verbose_name": "Subject Consent (Uganda)",
                "verbose_name_plural": "Subject Consents (Uganda)",
            },
        ),
    ]
