# Generated by Django 4.2.1 on 2023-05-24 02:04

from django.db import migrations, models
import edc_model_fields.fields.other_charfield


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0046_alter_healtheconomicsassets_options_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicsassets",
            name="cooking_fuel_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER cooking fuel, specify",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicsassets",
            name="floor_material_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER floor material, specify",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicsassets",
            name="lighting_source_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER lighting source, specify",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicsassets",
            name="roof_material_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER roof material, specify",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicsassets",
            name="toilet_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER type of toilet, specify",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicsassets",
            name="water_source_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER water source, specify",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsassets",
            name="cooking_fuel_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER cooking fuel, specify",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsassets",
            name="floor_material_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER floor material, specify",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsassets",
            name="lighting_source_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER lighting source, specify",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsassets",
            name="roof_material_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER roof material, specify",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsassets",
            name="toilet_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER type of toilet, specify",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsassets",
            name="water_source_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER water source, specify",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="external_wall_material_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER external wall material, specify",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="external_window_material_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER external window material, specify",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="water_source",
            field=models.CharField(
                choices=[
                    ("piped_into_plot", "Piped into dwelling/yard plot"),
                    ("piped_to_neighbour", "Piped to neighbour"),
                    ("standpipe", "Public tap/standpipe"),
                    ("borehole", "Tube well or borehole"),
                    ("protected_well", "Protected dug well"),
                    ("protected_spring", "Protected spring"),
                    ("rainwater", "Rainwater"),
                    (
                        "bottled_water_improved",
                        "Bottled water, improved source for cooking/hand washing (1-7)",
                    ),
                    ("unprotected_well", "Unprotected dug well"),
                    ("unprotected_spring", "Unprotected spring"),
                    ("tanker", "Tanker truck/cart with small tank"),
                    ("surface_water", "Surface water (river etc.)"),
                    (
                        "bottled_water_unimproved",
                        "Bottle water, unimproved source for cooking/hand washing (9-12)",
                    ),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="What is the main source of drinking water for the household?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="external_wall_material_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER external wall material, specify",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="external_window_material_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER external window material, specify",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="water_source",
            field=models.CharField(
                choices=[
                    ("piped_into_plot", "Piped into dwelling/yard plot"),
                    ("piped_to_neighbour", "Piped to neighbour"),
                    ("standpipe", "Public tap/standpipe"),
                    ("borehole", "Tube well or borehole"),
                    ("protected_well", "Protected dug well"),
                    ("protected_spring", "Protected spring"),
                    ("rainwater", "Rainwater"),
                    (
                        "bottled_water_improved",
                        "Bottled water, improved source for cooking/hand washing (1-7)",
                    ),
                    ("unprotected_well", "Unprotected dug well"),
                    ("unprotected_spring", "Unprotected spring"),
                    ("tanker", "Tanker truck/cart with small tank"),
                    ("surface_water", "Surface water (river etc.)"),
                    (
                        "bottled_water_unimproved",
                        "Bottle water, unimproved source for cooking/hand washing (9-12)",
                    ),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="What is the main source of drinking water for the household?",
            ),
        ),
    ]
