# Generated by Django 4.1.7 on 2023-04-06 19:10

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0024_historicalhtninitialreview_med_start_date_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="dminitialreview",
            old_name="med_start_ago",
            new_name="rx_init_ago",
        ),
        migrations.RenameField(
            model_name="dminitialreview",
            old_name="dx_estimated_date",
            new_name="dx_calculated_date",
        ),
        migrations.RenameField(
            model_name="historicaldminitialreview",
            old_name="dx_estimated_date",
            new_name="dx_calculated_date",
        ),
        migrations.RenameField(
            model_name="historicaldminitialreview",
            old_name="med_start_ago",
            new_name="rx_init_ago",
        ),
        migrations.RenameField(
            model_name="hivinitialreview",
            old_name="arv_initiated",
            new_name="rx_init",
        ),
        migrations.RenameField(
            model_name="hivinitialreview",
            old_name="arv_initiation_ago",
            new_name="rx_init_ago",
        ),
        migrations.RenameField(
            model_name="hivinitialreview",
            old_name="arv_initiation_actual_date",
            new_name="rx_init_date",
        ),
        migrations.RenameField(
            model_name="historicalhivinitialreview",
            old_name="dx_estimated_date",
            new_name="dx_calculated_date",
        ),
        migrations.RenameField(
            model_name="historicalhivinitialreview",
            old_name="arv_initiated",
            new_name="rx_init",
        ),
        migrations.RenameField(
            model_name="historicalhivinitialreview",
            old_name="arv_initiation_ago",
            new_name="rx_init_ago",
        ),
        migrations.RenameField(
            model_name="historicalhivinitialreview",
            old_name="arv_initiation_actual_date",
            new_name="rx_init_date",
        ),
        migrations.RenameField(
            model_name="htninitialreview",
            old_name="med_start_ago",
            new_name="rx_init_ago",
        ),
        migrations.RenameField(
            model_name="historicalhtninitialreview",
            old_name="med_start_ago",
            new_name="rx_init_ago",
        ),
        migrations.RenameField(
            model_name="historicalhtninitialreview",
            old_name="dx_estimated_date",
            new_name="dx_calculated_date",
        ),
    ]
