# Generated by Django 4.1.7 on 2023-05-05 04:13

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0039_icecapa_historicalicecapa_historicaleq5d3l_eq5d3l_and_more",
        ),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="historicalhivmedicationadherence",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Medication Adherence (HIV)",
                "verbose_name_plural": "historical Medication Adherence (HIV)",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalhtnmedicationadherence",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Medication Adherence (Hypertension)",
                "verbose_name_plural": "historical Medication Adherence (Hypertension)",
            },
        ),
        migrations.AlterModelOptions(
            name="hivmedicationadherence",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Medication Adherence (HIV)",
                "verbose_name_plural": "Medication Adherence (HIV)",
            },
        ),
        migrations.AlterModelOptions(
            name="htnmedicationadherence",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Medication Adherence (Hypertension)",
                "verbose_name_plural": "Medication Adherence (Hypertension)",
            },
        ),
    ]
