# Generated by Django 4.2.4 on 2023-08-26 22:49

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0113_alter_htnreview_device_created_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dmmedicationadherence",
            name="visual_score_confirmed",
            field=models.IntegerField(
                help_text="%",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="<B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.",
            ),
        ),
        migrations.AlterField(
            model_name="familyhistory",
            name="dm_in_household",
            field=models.CharField(
                choices=[
                    ("No", "No"),
                    ("yes_spouse", "Yes, my spouse"),
                    ("yes_parents", "Yes, one of my parents living with me"),
                    ("yes_relative", "Yes, another relative living with me"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Do you know if anyone else in your household has diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="familyhistory",
            name="hiv_in_household",
            field=models.CharField(
                choices=[
                    ("No", "No"),
                    ("yes_spouse", "Yes, my spouse"),
                    ("yes_parents", "Yes, one of my parents living with me"),
                    ("yes_relative", "Yes, another relative living with me"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Do you know if anyone else in your household has HIV?",
            ),
        ),
        migrations.AlterField(
            model_name="familyhistory",
            name="htn_in_household",
            field=models.CharField(
                choices=[
                    ("No", "No"),
                    ("yes_spouse", "Yes, my spouse"),
                    ("yes_parents", "Yes, one of my parents living with me"),
                    ("yes_relative", "Yes, another relative living with me"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Do you know if anyone else in your household has high blood pressure?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmmedicationadherence",
            name="visual_score_confirmed",
            field=models.IntegerField(
                help_text="%",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="<B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfamilyhistory",
            name="dm_in_household",
            field=models.CharField(
                choices=[
                    ("No", "No"),
                    ("yes_spouse", "Yes, my spouse"),
                    ("yes_parents", "Yes, one of my parents living with me"),
                    ("yes_relative", "Yes, another relative living with me"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Do you know if anyone else in your household has diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfamilyhistory",
            name="hiv_in_household",
            field=models.CharField(
                choices=[
                    ("No", "No"),
                    ("yes_spouse", "Yes, my spouse"),
                    ("yes_parents", "Yes, one of my parents living with me"),
                    ("yes_relative", "Yes, another relative living with me"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Do you know if anyone else in your household has HIV?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfamilyhistory",
            name="htn_in_household",
            field=models.CharField(
                choices=[
                    ("No", "No"),
                    ("yes_spouse", "Yes, my spouse"),
                    ("yes_parents", "Yes, one of my parents living with me"),
                    ("yes_relative", "Yes, another relative living with me"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Do you know if anyone else in your household has high blood pressure?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivmedicationadherence",
            name="visual_score_confirmed",
            field=models.IntegerField(
                help_text="%",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="<B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtnmedicationadherence",
            name="visual_score_confirmed",
            field=models.IntegerField(
                help_text="%",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="<B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.",
            ),
        ),
        migrations.AlterField(
            model_name="hivmedicationadherence",
            name="visual_score_confirmed",
            field=models.IntegerField(
                help_text="%",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="<B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.",
            ),
        ),
        migrations.AlterField(
            model_name="htnmedicationadherence",
            name="visual_score_confirmed",
            field=models.IntegerField(
                help_text="%",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="<B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.",
            ),
        ),
    ]
