# Generated by Django 4.1.2 on 2023-02-13 15:12

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0013_alter_bloodresultsfbc_results_abnormal_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalotherbaselinedata",
            name="activity_combined_mn_avg_day",
            field=models.IntegerField(
                blank=True,
                help_text="Number of minutes in a typical day",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(1080),
                ],
                verbose_name="On an average day, how many MINUTES do you spend on all physical activities combined? (moderate or vigorous-intensity work activities, exercise, sports and fitness)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherbaselinedata",
            name="activity_work",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="See interviewer notes above.",
                max_length=15,
                null=True,
                verbose_name="Does your work involve moderate or vigorous-intensity physical activity?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherbaselinedata",
            name="smoker_current_duration_estimated_date",
            field=models.DateField(
                blank=True,
                null=True,
                verbose_name="Estimated date smoker has been smoking since?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherbaselinedata",
            name="smoking_status",
            field=models.CharField(
                choices=[
                    ("smoker", "Currently smoke"),
                    ("former_smoker", "Used to smoke but stopped"),
                    ("nonsmoker", "Never smoked"),
                ],
                max_length=15,
                verbose_name="Which of these options describes you?",
            ),
        ),
        migrations.AlterField(
            model_name="otherbaselinedata",
            name="activity_combined_mn_avg_day",
            field=models.IntegerField(
                blank=True,
                help_text="Number of minutes in a typical day",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(1080),
                ],
                verbose_name="On an average day, how many MINUTES do you spend on all physical activities combined? (moderate or vigorous-intensity work activities, exercise, sports and fitness)",
            ),
        ),
        migrations.AlterField(
            model_name="otherbaselinedata",
            name="activity_work",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="See interviewer notes above.",
                max_length=15,
                null=True,
                verbose_name="Does your work involve moderate or vigorous-intensity physical activity?",
            ),
        ),
        migrations.AlterField(
            model_name="otherbaselinedata",
            name="smoker_current_duration_estimated_date",
            field=models.DateField(
                blank=True,
                null=True,
                verbose_name="Estimated date smoker has been smoking since?",
            ),
        ),
        migrations.AlterField(
            model_name="otherbaselinedata",
            name="smoking_status",
            field=models.CharField(
                choices=[
                    ("smoker", "Currently smoke"),
                    ("former_smoker", "Used to smoke but stopped"),
                    ("nonsmoker", "Never smoked"),
                ],
                max_length=15,
                verbose_name="Which of these options describes you?",
            ),
        ),
    ]
