{% comment %}Button to add a subject consent{% endcomment %}

<a id="subjectconsent_add_{{ screening_identifier }}"
 	title="{{ title }}"
    class="btn btn-warning btn-sm" data-toggle="tooltip"  data-placement="right"
        {% if perms.intecomm_consent.view_subjectconsent or perms.intecomm_consent.change_subjectconsent %}
        	href="{{ add_consent_url }}"
        {% else %}
        	disabled
        {% endif %}>
     Consent (v{{ consent_version }})
</a>
