# Generated by Django 4.1.7 on 2023-04-19 19:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_lists", "0005_htnmanagement_and_more"),
        ("intecomm_subject", "0032_historicalnextappointment_best_visit_code_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="clinicalreviewbaseline",
            name="dm_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Was this diagnosis reported at screening",
            ),
        ),
        migrations.AddField(
            model_name="clinicalreviewbaseline",
            name="hiv_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Was this diagnosis reported at screening",
            ),
        ),
        migrations.AddField(
            model_name="clinicalreviewbaseline",
            name="htn_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Was this diagnosis reported at screening",
            ),
        ),
        migrations.AddField(
            model_name="historicalclinicalreviewbaseline",
            name="dm_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Was this diagnosis reported at screening",
            ),
        ),
        migrations.AddField(
            model_name="historicalclinicalreviewbaseline",
            name="hiv_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Was this diagnosis reported at screening",
            ),
        ),
        migrations.AddField(
            model_name="historicalclinicalreviewbaseline",
            name="htn_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Was this diagnosis reported at screening",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="best_visit_code",
            field=models.CharField(
                choices=[
                    ("1000", "1000"),
                    ("1010", "1010"),
                    ("1020", "1020"),
                    ("1030", "1030"),
                    ("1040", "1040"),
                    ("1050", "1050"),
                    ("1060", "1060"),
                    ("1070", "1070"),
                    ("1080", "1080"),
                    ("1090", "1090"),
                    ("1100", "1100"),
                    ("1110", "1110"),
                    ("1120", "1120"),
                ],
                help_text="Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required.",
                max_length=15,
                null=True,
                verbose_name="Which study visit code is closest to this appointment date",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="best_visit_code",
            field=models.CharField(
                choices=[
                    ("1000", "1000"),
                    ("1010", "1010"),
                    ("1020", "1020"),
                    ("1030", "1030"),
                    ("1040", "1040"),
                    ("1050", "1050"),
                    ("1060", "1060"),
                    ("1070", "1070"),
                    ("1080", "1080"),
                    ("1090", "1090"),
                    ("1100", "1100"),
                    ("1110", "1110"),
                    ("1120", "1120"),
                ],
                help_text="Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required.",
                max_length=15,
                null=True,
                verbose_name="Which study visit code is closest to this appointment date",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="missed_reasons",
            field=models.ManyToManyField(
                blank=True, to="intecomm_lists.subjectvisitmissedreasons"
            ),
        ),
    ]
